ProSHADE: Namespace Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented namespace members with links to the namespaces they belong to:

### - f -

- figureDataType() : ProSHADE_internal_io
- findAllDisconnectedIslands() : ProSHADE_internal_peakSearch
- findAllPointNeighbours() : ProSHADE_internal_peakSearch
- findAllPointsAboveNeighbours() : ProSHADE_internal_peakSearch
- findAllPrimes() : ProSHADE_internal_maths
- findAllSmoothedZScorePeaksWithNeighbours() : ProSHADE_internal_peakSearch
- findExpectedPeakRotations() : ProSHADE_internal_symmetry
- findHighestValueInMap() : ProSHADE_internal_overlay
- findIcos10C3s() : ProSHADE_internal_symmetry
- findIcos15C2s() : ProSHADE_internal_symmetry
- findIcos6C5s() : ProSHADE_internal_symmetry
- findMAPCOMValues() : ProSHADE_internal_mapManip
- findMissingAxes() : ProSHADE_internal_symmetry
- findMissingAxesDual() : ProSHADE_internal_symmetry
- findMissingAxesTriple() : ProSHADE_internal_symmetry
- findMissingAxisPoints() : ProSHADE_internal_symmetry
- findOcta3C4s() : ProSHADE_internal_symmetry
- findOcta4C3s() : ProSHADE_internal_symmetry
- findOcta6C2s() : ProSHADE_internal_symmetry
- findPDBCOMValues() : ProSHADE_internal_mapManip
- findPeaksByHeightBoundaries() : ProSHADE_internal_symmetry
- findPeaksCSymmetry() : ProSHADE_internal_symmetry
- findPredictedAxesHeights() : ProSHADE_internal_symmetry
- findRotMatMatchingVectors() : ProSHADE_internal_maths
- findSymmetryUsingFold() : ProSHADE_internal_symmetry
- findTetra3C2s() : ProSHADE_internal_symmetry
- findTetra4C3s() : ProSHADE_internal_symmetry
- findVectorFromThreeVAndThreeD() : ProSHADE_internal_maths
- findVectorFromTwoVAndTwoD() : ProSHADE_internal_maths
- freeTranslationFunctionMemory() : ProSHADE_internal_overlay